@@ -3,10 +3,12 @@ from pymbse.query.model_api.notebook_script_api import (
     NotebookModelAPI,
     ScriptModelAPI,
     NotebookScriptModelAPI,
+    GitLabNotebookModelAPI,
 )
 
 model_type_to_api = {
     ModelType.NOTEBOOK: NotebookModelAPI,
     ModelType.SCRIPT: ScriptModelAPI,
     ModelType.NOTEBOOK_SCRIPT: NotebookScriptModelAPI,
+    ModelType.GITLAB_NOTEBOOK: GitLabNotebookModelAPI
 }
