@@ -5,6 +5,11 @@ import requests
 
 from pymbse.commons import text_file
 from pymbse.query.config.numpy_encoder import NumpyEncoder
+from pymbse.query.model_api.executor.gitlab_executor import GitLabExecutor
+from pymbse.query.model_api.executor.notebook_script_executor import (
+    ScriptExecutor,
+    NotebookExecutor,
+)
 from pymbse.query.model_api.executor.notebook_converter import (
     convert_ipynb_to_html,
     create_script_if_missing_or_outdated,
@@ -36,12 +41,12 @@ def post_model_snapshot_to_cache_decorator(execute_notebook: Callable) -> Callab
         :param model_api: ModelAPI instance
         """
         cached_model_snapshot = get_cached_model_snapshot(
-            model_api.ip_with_port, model_api.root_model_metadata_hash
+            model_api.cache_db_ip_with_port, model_api.root_model_metadata_hash
         )
         if cached_model_snapshot is None:
             executed_model_snapshot = execute_notebook(model_api)
             post_model_snapshot_to_cache(
-                model_api.ip_with_port,
+                model_api.cache_db_ip_with_port,
                 executed_model_snapshot,
                 model_api.root_model_metadata_hash,
             )
@@ -67,7 +72,7 @@ def get_model_snapshot_from_cache_decorator(execute_script: Callable) -> Callabl
         """
 
         cached_model = get_cached_model_snapshot(
-            model_api.ip_with_port, model_api.root_model_metadata_hash
+            model_api.cache_db_ip_with_port, model_api.root_model_metadata_hash
         )
         if cached_model is None:
             print(
@@ -76,7 +81,7 @@ def get_model_snapshot_from_cache_decorator(execute_script: Callable) -> Callabl
             )
             cached_model = execute_script(model_api)
             post_model_snapshot_to_cache(
-                model_api.ip_with_port, cached_model, model_api.root_model_metadata_hash
+                model_api.cache_db_ip_with_port, cached_model, model_api.root_model_metadata_hash
             )
 
         return cached_model
@@ -85,7 +90,7 @@ def get_model_snapshot_from_cache_decorator(execute_script: Callable) -> Callabl
 
 
 def get_cached_model_snapshot(
-    ip_with_port: str, model_snapshot_hash: str
+        ip_with_port: str, model_snapshot_hash: str
 ) -> Union[None, ModelSnapshot]:
     """Function getting a cached model from a database
 
@@ -106,7 +111,7 @@ def get_cached_model_snapshot(
 
 
 def post_model_snapshot_to_cache(
-    ip_with_port: str, model_snapshot: ModelSnapshot, model_snapshot_hash: str
+        ip_with_port: str, model_snapshot: ModelSnapshot, model_snapshot_hash: str
 ) -> None:
     """Function posting a model snapshot with model_api to the model_api database
 
@@ -126,7 +131,7 @@ def post_model_snapshot_to_cache(
         return None
 
     if response.status_code != 201:
-        raise ConnectionError("Could not post model snapshot to url: %s" % url)
+        raise requests.exceptions.ConnectionError("Could not post model snapshot to url: %s" % url)
 
 
 class NotebookModelAPI(ModelAPI):
@@ -145,7 +150,7 @@ class NotebookModelAPI(ModelAPI):
 
     def get_ipynb_report(self) -> str:
         """Method returning an ipynb report content. It executes a notebook with papermill and returns an ipynb file
-        content.
+        content. The cache is skipped due to the size of the file.
 
         :return: a string containing the ipynb report content
         """
@@ -169,6 +174,27 @@ class NotebookModelAPI(ModelAPI):
         ).execute_with_snapshot()
 
 
+class GitLabNotebookModelAPI(NotebookModelAPI):
+    def get_html_report(self) -> str:
+        ge = GitLabExecutor(model_dependency_config=self.root_model_config,
+                            input_parameters=self.input_parameters,
+                            input_files=self.input_files)
+        job_id = ge._execute_without_figures_of_merit_and_artefacts()
+        return ge._get_artefact(job_id, ge._get_report_name())
+
+    def get_ipynb_report(self) -> str:
+        ge = GitLabExecutor(model_dependency_config=self.root_model_config,
+                              input_parameters=self.input_parameters,
+                              input_files=self.input_files)
+        job_id = ge._execute_without_figures_of_merit_and_artefacts()
+        return ge._get_artefact(job_id, ge._get_notebook_name())
+
+    def execute(self) -> ModelSnapshot:
+        return GitLabExecutor(model_dependency_config=self.root_model_config,
+                              input_parameters=self.input_parameters,
+                              input_files=self.input_files).execute_with_snapshot()
+
+
 class ScriptModelAPI(ModelAPI):
     @get_model_snapshot_from_cache_decorator
     def execute(self) -> ModelSnapshot:
@@ -180,7 +206,7 @@ class ScriptModelAPI(ModelAPI):
 
 
 def create_script_if_missing_or_outdated_decorator(
-    script_dependent_function: Callable,
+        script_dependent_function: Callable,
 ) -> Callable:
     """
 
